@@ -65,7 +65,7 @@ public:
 
 public slots:
 
-    void saveConfig()
+    void saveConfig() Q_DECL_OVERRIDE
     {
         logDebug() << "Saving config from Samba Options...";
 
@@ -77,13 +77,13 @@ public slots:
         sambaConfiguration->setNetbiosPaths(sambaFileList->paths(netbiosPathsId));
     }
 
-    void defaultConfig()
+    void defaultConfig() Q_DECL_OVERRIDE
     {
         // TODO Find a way to read the configuration per default
         readConfig();
     }
 
-    void readConfig()
+    void readConfig() Q_DECL_OVERRIDE
     {
         SambaConfiguration *sambaConfiguration = Globals::instance()
                                                      .findLogMode(QStringLiteral(SAMBA_LOG_MODE_ID))
@@ -97,7 +97,7 @@ public slots:
     }
 
 protected:
-    bool isValid() const
+    bool isValid() const Q_DECL_OVERRIDE
     {
         if (sambaFileList->isOneOfCategoryEmpty() == true) {
             logDebug() << "Samba configuration not valid";
